# Delete and stop the service if it already exists.
if (Get-Service timebeat -ErrorAction SilentlyContinue) {
  $service = Get-WmiObject -Class Win32_Service -Filter "name='timebeat'"
  $service.StopService()
  Start-Sleep -s 1
  $service.delete()
}

$workdir = Split-Path $MyInvocation.MyCommand.Path

# Create the new service.
New-Service -name timebeat `
  -displayName Timebeat `
  -binaryPathName "`"$workdir\timebeat.exe`" --environment=windows_service -c `"$workdir\timebeat.yml`" --path.home `"$workdir`" --path.data `"$env:PROGRAMDATA\timebeat`" --path.logs `"$env:PROGRAMDATA\timebeat\logs`" -E logging.files.redirect_stderr=true"

# Attempt to set the service to delayed start using sc config.
Try {
  Start-Process -FilePath sc.exe -ArgumentList 'config timebeat start= delayed-auto'
}
Catch { Write-Host -f red "An error occured setting the service to delayed start." }
